@@ -25,13 +25,11 @@ class StatelessAccumulator(Accumulator):
 
     def push(self, data):
         value = super(StatelessAccumulator, self).push(data)
-        if value is None:
-            return None
 
         try:
             bool_flag = np.all(np.isnan(value))
             if bool_flag:
-                return None
+                return np.nan
         except TypeError:
             pass
 
@@ -48,14 +46,74 @@ class Latest(StatelessAccumulator):
 
     def push(self, data):
         value = super(Latest, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
         self._latest = value
 
     def result(self):
         return self._latest
 
 
+class Diff(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(Diff, self).__init__(dependency)
+        _checkParameterList(dependency)
+        self._returnSize = 1
+        self._diff = np.nan
+        self._curr = np.nan
+        self._previous = np.nan
+
+    def push(self, data):
+        value = super(Diff, self).push(data)
+        if np.isnan(value):
+            return np.isnan
+        self._previous = self._curr
+        self._curr = value
+
+    def result(self):
+        return self._curr - self._previous
+
+
+class SimpleReturn(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(SimpleReturn, self).__init__(dependency)
+        _checkParameterList(dependency)
+        self._returnSize = 1
+        self._diff = np.nan
+        self._curr = np.nan
+        self._previous = np.nan
+
+    def push(self, data):
+        value = super(SimpleReturn, self).push(data)
+        if np.isnan(value):
+            return np.isnan
+        self._previous = self._curr
+        self._curr = value
+
+    def result(self):
+        return self._curr / self._previous - 1.
+
+
+class LogReturn(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(LogReturn, self).__init__(dependency)
+        _checkParameterList(dependency)
+        self._returnSize = 1
+        self._diff = np.nan
+        self._curr = np.nan
+        self._previous = np.nan
+
+    def push(self, data):
+        value = super(LogReturn, self).push(data)
+        if np.isnan(value):
+            return np.isnan
+        self._previous = self._curr
+        self._curr = value
+
+    def result(self):
+        return math.log(self._curr / self._previous)
+
+
 class Positive(StatelessAccumulator):
     def __init__(self, dependency='x'):
         super(Positive, self).__init__(dependency)
@@ -65,8 +123,8 @@ class Positive(StatelessAccumulator):
 
     def push(self, data):
         value = super(Positive, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
 
         if value > 0.:
             self._pos = value
@@ -88,8 +146,8 @@ class Negative(StatelessAccumulator):
 
     def push(self, data):
         value = super(Negative, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
 
         if value < 0.:
             self._neg = value
@@ -112,8 +170,8 @@ class Max(StatelessAccumulator):
 
     def push(self, data):
         value = super(Max, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
         if self._first:
             self._currentMax = value
             self._first = False
@@ -135,8 +193,8 @@ class Minimum(StatelessAccumulator):
 
     def push(self, data):
         value = super(Minimum, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
         if self._first:
             self._currentMin = value
             self._first = False
@@ -158,8 +216,8 @@ class Sum(StatelessAccumulator):
 
     def push(self, data):
         value = super(Sum, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
         if self._first:
             self._currentSum = value
             self._first = False
@@ -180,8 +238,8 @@ class Average(StatelessAccumulator):
 
     def push(self, data):
         value = super(Average, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
         if self._currentCount == 0:
             self._currentSum = value
         else:
@@ -204,8 +262,8 @@ class XAverage(StatelessAccumulator):
 
     def push(self, data):
         value = super(XAverage, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
         if self._count == 0:
             self._average = value
         else:
@@ -244,8 +302,8 @@ class Variance(StatelessAccumulator):
 
     def push(self, data):
         value = super(Variance, self).push(data)
-        if value is None:
-            return
+        if np.isnan(value):
+            return np.nan
         self._currentSum += value
         self._currentSumSquare += value * value
         self._currentCount += 1
@@ -274,8 +332,8 @@ class Correlation(StatelessAccumulator):
 
     def push(self, data):
         value = super(Correlation, self).push(data)
-        if value is None:
-            return
+        if np.any(np.isnan(value)):
+            return np.nan
         self._runningSumLeft = self._runningSumLeft + value[0]
         self._runningSumRight = self._runningSumRight + value[1]
         self._runningSumSquareLeft = self._runningSumSquareLeft + value[0] * value[0]
