@@ -9,6 +9,7 @@ from PyFin.Math.Accumulators.IAccumulators import TruncatedValueHolder
 from PyFin.Math.Accumulators.IAccumulators import Exp
 from PyFin.Math.Accumulators.IAccumulators import Log
 from PyFin.Math.Accumulators.IAccumulators import Sqrt
+from PyFin.Math.Accumulators.IAccumulators import Sign
 from PyFin.Math.Accumulators.IAccumulators import Abs
 from PyFin.Math.Accumulators.IAccumulators import Pow
 from PyFin.Math.Accumulators.IAccumulators import Acos
@@ -17,6 +18,9 @@ from PyFin.Math.Accumulators.IAccumulators import Asin
 from PyFin.Math.Accumulators.IAccumulators import Asinh
 
 from PyFin.Math.Accumulators.StatelessAccumulators import Latest
+from PyFin.Math.Accumulators.StatelessAccumulators import Diff
+from PyFin.Math.Accumulators.StatelessAccumulators import SimpleReturn
+from PyFin.Math.Accumulators.StatelessAccumulators import LogReturn
 from PyFin.Math.Accumulators.StatelessAccumulators import Positive
 from PyFin.Math.Accumulators.StatelessAccumulators import Negative
 from PyFin.Math.Accumulators.StatelessAccumulators import Max
@@ -57,6 +61,7 @@ from PyFin.Math.Accumulators.Performancers import MovingSortino
 __all__ = ["Exp",
            "Log",
            "Sqrt",
+           "Sign",
            "Abs",
            "Pow",
            "Acos",
@@ -64,6 +69,9 @@ __all__ = ["Exp",
            "Asin",
            "Asinh",
            "Latest",
+           "Diff",
+           "SimpleReturn",
+           "LogReturn",
            "Positive",
            "Negative",
            "Max",
@@ -98,5 +106,4 @@ __all__ = ["Exp",
            "MovingAverageDrawdown",
            "MovingMaxDrawdown",
            "MovingSharp",
-           "MovingSortino",
-           "Timeseries"]
+           "MovingSortino"]
